package com.tanpu.feo.feojob.dao;

import com.baomidou.mybatisplus.extension.spring.MybatisSqlSessionFactoryBean;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionTemplate;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.jdbc.DataSourceBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.Resource;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.support.TransactionTemplate;

import javax.sql.DataSource;


@Configuration
@MapperScan(value = {"com.tanpu.feo.feojob.dao.personaluser.mapper"}, sqlSessionTemplateRef = "personaluserSqlSessionTemplate")
public class PersonalUserDataSourceConfig {

    @Bean(name = "personaluserDataSource")
    @ConfigurationProperties(prefix = "spring.datasource.personaluser")
    public DataSource setDataSource() {
        return DataSourceBuilder.create().build();
    }

    @Bean(name = "personaluserTransactionManager")
    public DataSourceTransactionManager setTransactionManager(@Qualifier("personaluserDataSource") DataSource dataSource) {
        return new DataSourceTransactionManager(dataSource);
    }

    @Bean(name = "personaluserSqlSessionFactory")
    public SqlSessionFactory setSqlSessionFactory(@Qualifier("personaluserDataSource") DataSource dataSource) throws Exception {
        MybatisSqlSessionFactoryBean bean = new MybatisSqlSessionFactoryBean();
        bean.setDataSource(dataSource);
        PathMatchingResourcePatternResolver resolver = new PathMatchingResourcePatternResolver();
        Resource[] resources1 = resolver.getResources("classpath:mapper/personaluser/*.xml");
        Resource[] resources = ArrayUtils.addAll(resources1);
        bean.setMapperLocations(resources);
        return bean.getObject();
    }

    @Bean(name = "personaluserSqlSessionTemplate")
    public SqlSessionTemplate setSqlSessionTemplate(@Qualifier("personaluserSqlSessionFactory") SqlSessionFactory sqlSessionFactory) throws Exception {
        return new SqlSessionTemplate(sqlSessionFactory);
    }

    @Bean(name = "personaluserTransactionTemplate")
    public TransactionTemplate transactionTemplate(@Qualifier("personaluserTransactionManager") PlatformTransactionManager transactionManager) {
        return new TransactionTemplate(transactionManager);
    }

    @Bean(name = "personaluserJdbcTemplate")
    public JdbcTemplate personaluserJdbcTemplate(@Qualifier("personaluserDataSource") DataSource dataSource) {
        return new JdbcTemplate(dataSource);
    }

    @Bean(name = "personaluserNamedParameterJdbcTemplate")
    public NamedParameterJdbcTemplate namedParameterJdbcTemplate(@Qualifier("personaluserJdbcTemplate") JdbcTemplate jdbcTemplate) {
        return new NamedParameterJdbcTemplate(jdbcTemplate);
    }
}

